@@ -2,7 +2,7 @@
 # Ebbe Library Enpoint
 # =============================================================================
 #
-from ebbe.functions import (
+from ebbe.iter import (
     as_chunks,
     fail_fast,
     uniq,
@@ -13,3 +13,9 @@ from ebbe.functions import (
     with_is_last,
     without_first
 )
+from ebbe.utils import (
+    noop,
+    getpath,
+    pathgetter,
+    sorted_uniq
+)
